@@ -31,7 +31,7 @@ int SCREEN_BPP=16;
 
 #define FONTSIZE 26
 
-#define BLANKTIME 300
+#define BLANKTIME 600
 
 int scrollength=8000;
 
@@ -64,7 +64,7 @@ int mixerstate=1, mixerfade=0;
 
 long activetime;
 
-char rootpath[MAXPATHLEN]="/kahuna/multimedia/video";
+char rootpath[MAXPATHLEN]="/kahuna/multimedia";
 char player[MAXPATHLEN]="/usr/local/bin/mplayer -quiet -v -fs -novm";
 char encoder[MAXPATHLEN]="/usr/local/bin/mencoder -v";
 
@@ -287,9 +287,15 @@ int file_select(struct direct *entry) {
 		if ( ( type == 4 ) || ( (ptr != NULL) &&
 		 (
 		    (strcmp(ptr, ".mp3") == 0)
+		    || (strcmp(ptr, ".xm") == 0)
+		    || (strcmp(ptr, ".mod") == 0)
+		    || (strcmp(ptr, ".s3m") == 0)
+		    || (strcmp(ptr, ".mid") == 0)
+		    || (strcmp(ptr, ".ogg") == 0)
 		    || (strcmp(ptr, ".mpg") == 0)
 		    || (strcmp(ptr, ".ogm") == 0)
 		    || (strcmp(ptr, ".avi") == 0)
+		    || (strcmp(ptr, ".wmv") == 0)
 		    || (strcmp(ptr, ".divx") == 0)
 		    || (strcmp(ptr, ".mov") == 0)
 		    || (strcmp(ptr, ".mkv") == 0)
@@ -1021,20 +1027,31 @@ int main( int argc, char *argv[] ) {
 							Mix_PlayChannel(-1, open_snd, 0);
 							SDL_Delay(1500);
 							sound_state(0);
-							sprintf( command, "%s \"%s\"", player, filename);
+							if (
+                     		                              ( strcmp(mime, ".ogg") == 0 )
+                                                            || ( strcmp(mime, ".mp3") == 0 )
+                                                            || ( strcmp(mime, ".xm") == 0 )
+                                                            || ( strcmp(mime, ".mod") == 0 )
+                                                            || ( strcmp(mime, ".mid") == 0 )
+                                                            || ( strcmp(mime, ".s3m") == 0 )
+                                                            ) {
+								sprintf( command, "./animemp3 \"%s\"", filename);
+							} else {
+								sprintf( command, "%s \"%s\"", player, filename);
+							}
+							printf ("%s \n", command );
 							system( command );
 							activetime=time(NULL);
-							printf ("%s (Directory)\n", command );
 							sound_state(1);
 							Mix_PlayChannel(-1, close_snd, 0);
 						}
-					} else if ( cursor.pane==1 ) {
+					} else {
 						Mix_PlayChannel(-1, open_snd, 0);
 						SDL_Delay(1500);
 						sound_state(0);
-						sprintf( command, "%s \"%s/\"*", player, filename);
-						system( command );
+						sprintf( command, "./animemp3 \"%s\"/*", filename);
 						printf ("%s (Directory)\n", command );
+						system( command );
 						sound_state(1);
 						Mix_PlayChannel(-1, close_snd, 0);
 					}
